read abstract method
Reads the given json object returning an Iterable of all matches found.
Implementation
Iterable<JsonPathMatch> read(dynamic json);
Reads the given json object returning an Iterable of all matches found.
Iterable<JsonPathMatch> read(dynamic json);